==> aidlab_sdk-0.0.1.tar.gz: android/src/main/kotlin/com/aidlab/aidlab_sdk/AidlabSdkHandler.kt <==
package com.aidlab.aidlab_sdk

import com.aidlab.sdk.communication.Signal
import io.flutter.embedding.engine.plugins.FlutterPlugin
import java.lang.IllegalArgumentException
import java.util.*

class AidlabSdkHandler(
        val aidlabHandler: AidlabHandler
): AidlabFlutter.PlatformAidlabSdk {

    private var aidlabSdkListener: AidlabFlutter.PlatformAidlabSdkDelegate? = null

    fun init(binding: FlutterPlugin.FlutterPluginBinding) {

        aidlabSdkListener = AidlabFlutter.PlatformAidlabSdkDelegate(binding.binaryMessenger)
        AidlabFlutter.PlatformAidlabSdk.setup(binding.binaryMessenger, this)
        AidlabBluetoothManager.listener = aidlabSdkListener
    }

    fun release() {
        AidlabBluetoothManager.stopScan()
        AidlabBluetoothManager.listener = null
    }

    override fun scanForDevices() {
        AidlabBluetoothManager.startScan()
    }

    override fun stopDeviceScan() {
        AidlabBluetoothManager.stopScan()
    }

    override fun connect(arg: AidlabFlutter.ConnectRequest?) {
        AidlabBluetoothManager.stopScan()
        val aidlab = AidlabBluetoothManager.addressToAidlab(arg!!.address)
        val signals = arg.signals.asIterable()
                .map { signalValue ->
                    Signal.values().asIterable().find {
                        it.value == signalValue
                    } ?: throw IllegalArgumentException("Failed to parse signal with value: $signalValue")
                }

        aidlab.connect(
                EnumSet.copyOf(signals),
                false,
                aidlabHandler
        )
    }



}

==> aidlab_sdk-0.0.3.tar.gz: android/src/main/kotlin/com/aidlab/aidlab_sdk/AidlabSdkHandler.kt <==
package com.aidlab.aidlab_sdk

import com.aidlab.sdk.communication.Signal
import io.flutter.embedding.engine.plugins.FlutterPlugin
import java.lang.IllegalArgumentException
import java.util.*

class AidlabSdkHandler(
        val aidlabHandler: AidlabHandler
): AidlabFlutter.PlatformAidlabSdk {

    private var aidlabSdkListener: AidlabFlutter.PlatformAidlabSdkDelegate? = null

    fun init(binding: FlutterPlugin.FlutterPluginBinding) {

        aidlabSdkListener = AidlabFlutter.PlatformAidlabSdkDelegate(binding.binaryMessenger)
        AidlabFlutter.PlatformAidlabSdk.setup(binding.binaryMessenger, this)
        AidlabBluetoothManager.listener = aidlabSdkListener
    }

    fun release() {
        AidlabBluetoothManager.stopScan()
        AidlabBluetoothManager.listener = null
    }

    override fun scanForDevices() {
        AidlabBluetoothManager.startScan()
    }

    override fun stopDeviceScan() {
        AidlabBluetoothManager.stopScan()
    }

    override fun connect(arg: AidlabFlutter.ConnectRequest?) {
        AidlabBluetoothManager.stopScan()
        val signals = arg!!.signals.asIterable()
                .map { signalValue ->
                    Signal.values().asIterable().find {
                        it.value == signalValue
                    } ?: throw IllegalArgumentException("Failed to parse signal with value: $signalValue")
                }

        AidlabBluetoothManager.connect(
                arg.address,
                EnumSet.copyOf(signals),
                aidlabHandler
        )
    }
}
